Returns the observations of individuals that had observations dropped for data cleaning.
Usage
# S3 method for class 'clean_s4t_ch'
print(x, ...)Returns the observations of individuals that had observations dropped for data cleaning.
# S3 method for class 'clean_s4t_ch'
print(x, ...)