Create site configuration for a simple linear arrangement of sites, where there are no branches.
Arguments
- sites_names
a character
vectorof the site names. Order indicates the direction of movement.- holdover_sites
a character
vectorof the sites where after passing, individuals can holdover (take 1 or more time intervals) before reaching the next site.- min_a
a
vectorof the minimum ageclass individuals in a site can be. Must be the same length and order assites_names- max_a
a
vectorof the maximum ageclass individuals in a site can be. Must be the same length and order assites_names- sites_to_pool
a named list of character vectors that contain the names of sites to be pooled together and treated as one site. See LINK VIGNETTE and details.