Plot apparent survival estimates from fitted s4t_cjs_ml or s4t_cjs_rstanobjects
Source: R/plot.R
plotSurvival.RdPlot apparent survival estimates from fitted s4t_cjs_ml or s4t_cjs_rstanobjects.
If the package geomtextpath is installed, the figure is more visually appealing.
Arguments
- x
a
s4t_cjsors4t_cjs_rstanobject- textsize
an integer for the font size to pass to
geomtextpath::geom_textsegment()- ...
passed to
dplyr::filter()for selecting particular survivals. Filters apparent survivals froms4t_cjs_ml$apparent_survors4t_cjs_rstan$apparent_surv
Examples
if (FALSE) { # \dontrun{
sim.dat <- sim_simple_s4t_ch(N = 2000)
m1 <- fit_s4t_cjs_rstan(p_formula = ~ t,
theta_formula = ~ a1 * a2 * s * j,
ageclass_formula = ageclass ~ FL,
fixed_age = TRUE,
s4t_ch = sim.dat$s4t_ch)
plotSurvival(m1)
} # }