Print summary of s4t_cjs_rstan
Arguments
- x
s4t_cjs_rstan object
- pars
vector of parameters to include (defaults to all parameters)
- probs
quantiles for credible intervals
- digits_summary
the number of significant digits to use when printing the summary
- include
logical scalar indicating whether to include the parameters named by the pars argument.
- ...
passed to
summarymethod for s4t_cjs_rstan object.