Read DART Basin TribPit observation files and combine with auxiliary age data
Source:R/dart_helper.R
read_DART_file.RdRead DART Basin TribPit observation files and combine with auxiliary age data
Usage
read_DART_file(
filepath,
aux_age_df,
DART_config = "https://www.cbr.washington.edu/downloads/paramest/sites_config.txt"
)Arguments
- filepath
the path to the DART Basin TribPit observation file or a vector of filepaths.
- aux_age_df
A data frame object in the same format as aux_age_df (see documentation for
s4t_ch)- DART_config
the path to a site configuration file
"site_config.txt"generated by Columbia Basin Research. If blank, defaults towww.cbr.washington.edu/downloads/paramest/sites_config.txt